@@ -27,6 +27,7 @@ enum ModuleType { UNKNOWN_ASG, CAPACITOR_ASG, INDUCTOR_ASG, RESISTOR_ASG,
 #define GATE_RESTR_STR	"RESTR"
 #define GATE_INDR_STR	"INDR"
 #define GATE_VAMP_STR   "VAMP"
+#define GATE_IAMP_STR   "IAMP"
 #define GATE_MSFET_STR  "MSFET"
 #define GATE_INVNOT_STR "INVNOT"
 #define GATE_VSOURCE	"VSOURCE"
@@ -34,7 +35,7 @@ enum ModuleType { UNKNOWN_ASG, CAPACITOR_ASG, INDUCTOR_ASG, RESISTOR_ASG,
 #define GATE_NULL_STR   "NL_GATE"
 
 
-int xc_print_asg_module(Clientdata *areastruct, module *m);
+int xc_print_asg_module(XCWindowData *areastruct, module *m);
 
 char *toString(int mt);
 int toModuleType(char *mtName);
