@@ -140,11 +140,11 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       set pintext [.dialog.pinself.right.list get $j]
       lappend pinlabels $pintext
       set tlab [label make pin "$pintext" "$x $y"]
-      label $tlab justify left
-      label $tlab justify middle
+      label $tlab anchor left
+      label $tlab anchor middle
       set nlab [element $tlab copy relative "-$halfspace 0"]
       label $nlab type normal
-      label $nlab justify right
+      label $nlab anchor right
       incr y $pinspace
       deselect selected
    }
@@ -156,11 +156,11 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       set pintext [.dialog.pinself.left.list get $j]
       lappend pinlabels $pintext
       set tlab [label make pin "$pintext" "$x $y"]
-      label $tlab justify right
-      label $tlab justify middle
+      label $tlab anchor right
+      label $tlab anchor middle
       set nlab [element $tlab copy relative "$halfspace 0"]
       label $nlab type normal
-      label $nlab justify left
+      label $nlab anchor left
       incr y $pinspace
       deselect selected
    }
@@ -173,11 +173,11 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       lappend pinlabels $pintext
       set tlab [label make pin "$pintext" "$x $y"]
       rotate $tlab 270
-      label $tlab justify right
-      label $tlab justify middle
+      label $tlab anchor right
+      label $tlab anchor middle
       set nlab [element $tlab copy relative "0 $halfspace"]
       label $nlab type normal
-      label $nlab justify left
+      label $nlab anchor left
       incr x $pinspace
       deselect selected
    }
@@ -190,19 +190,19 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       lappend pinlabels $pintext
       set tlab [label make pin "$pintext" "$x $y"]
       rotate $tlab 90
-      label $tlab justify right
-      label $tlab justify middle
+      label $tlab anchor right
+      label $tlab anchor middle
       set nlab [element $tlab copy relative "0 -$halfspace"]
       label $nlab type normal
-      label $nlab justify left
+      label $nlab anchor left
       incr x $pinspace
       deselect selected
    }
 
    deselect selected
    set nlab [label make "$symbolname" {0 0}]
-   label $nlab justify middle
-   label $nlab justify center
+   label $nlab anchor middle
+   label $nlab anchor center
    element $nlab color set blue
 
    deselect selected
@@ -215,7 +215,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
    }
 
    set nlab [label make "{Parameter class} {Parameter index}" "0 -$pinspace"]
-   label $nlab justify center
+   label $nlab anchor center
    element $nlab color set blue
    deselect selected
 
@@ -247,7 +247,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
          set x [expr ([lindex $bbox 2] + [lindex $bbox 0]) / 2]
          set y [expr [lindex $bbox 1] - $pinspace]
          set nlab [label make info "$subckttext" "$x $y"] 
-         label $nlab justify center
+         label $nlab anchor center
          deselect selected
          set y [expr $y - $pinspace]
          set nlab [label make info "spice-1:.ends" "$x $y"] 
@@ -285,7 +285,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
 
    deselect selected
    set nlab [label make info "$itext" "0 $y"] 
-   label $nlab justify center
+   label $nlab anchor center
 
    if {$noschem == 1} {
       deselect selected
@@ -296,7 +296,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
       set itext [list {Text "spice@1:%F"}]
       lappend itext [subst {Text "$filename"}]
       set nlab [label make info "$itext" "0 $y"]
-      label $nlab justify center
+      label $nlab anchor center
       deselect selected
       pop
    } else {
