@@ -948,9 +948,9 @@ void swapschem(int allow_create, int libnum, char *fullname)
 	       NEW_LABEL(pinlab, topobject);
 	       (*pinlab)->pin = lpin->pin;
 	       (*pinlab)->color = lpin->color;
-	       (*pinlab)->rotation = 0;
+	       (*pinlab)->rotation = 0.0;
 	       (*pinlab)->scale = 1.0;
-	       (*pinlab)->justify = areawin->justify; 
+	       (*pinlab)->anchor = areawin->anchor; 
 	       (*pinlab)->position.x = 0;
 	       (*pinlab)->position.y = topobject->parts * (TEXTHEIGHT + 10);
 	       (*pinlab)->passed = NULL;
