@@ -275,7 +275,7 @@ void setoptionmenu()
 	    return;
 	 case LABEL:
 	    mlabel = SELTOLABEL(mselect);
-	    setfontmarks(mlabel->string->data.font, mlabel->justify);
+	    setfontmarks(mlabel->string->data.font, mlabel->anchor);
 	    return;
       }
    }
@@ -1009,7 +1009,9 @@ Boolean selectarea(objectptr selobj, XPoint *boxpts, short level)
 	   XPoint adj;
 	   labelptr slab = TOLABEL(curgen);
 	   short j, state, isect, tmpl1, tmpl2;
+	   int padding;
 	   TextExtents tmpext;
+	   TextLinesInfo tlinfo;
 
 	   selected = False;
 
@@ -1025,14 +1027,18 @@ Boolean selectarea(objectptr selobj, XPoint *boxpts, short level)
 
 	   if (slab->pin) {
 	      for (j = 0; j < 4; j++) 
-		 pinadjust(slab->justify, &(newboxpts[j].x),
+		 pinadjust(slab->anchor, &(newboxpts[j].x),
 			&(newboxpts[j].y), -1);
 	   }
 
-	   tmpext = ULength(slab, areawin->topinstance, 0, NULL);
-	   adj.x = (slab->justify & NOTLEFT ? (slab->justify & RIGHT ? 
+	   tlinfo.dostop = 0;
+	   tlinfo.tbreak = NULL;
+	   tlinfo.padding = NULL;
+
+	   tmpext = ULength(slab, areawin->topinstance, &tlinfo);
+	   adj.x = (slab->anchor & NOTLEFT ? (slab->anchor & RIGHT ? 
 			tmpext.maxwidth : tmpext.maxwidth >> 1) : 0);
-	   adj.y = (slab->justify & NOTBOTTOM ? (slab->justify & TOP ? 
+	   adj.y = (slab->anchor & NOTBOTTOM ? (slab->anchor & TOP ? 
 			tmpext.ascent : (tmpext.ascent + tmpext.base) >> 1)
 			: tmpext.base);
 
@@ -1045,9 +1051,16 @@ Boolean selectarea(objectptr selobj, XPoint *boxpts, short level)
 	      if (locpos < 0) continue;	  /* only look at printable characters */
 	      if (strptr->type == RETURN) tmpl2 = 0;
 	      tmpl1 = tmpl2;
-	      tmpext = ULength(slab, areawin->topinstance, j + 1, NULL);
+	      tlinfo.dostop = j + 1;
+	      tmpext = ULength(slab, areawin->topinstance, &tlinfo);
 	      tmpl2 = tmpext.maxwidth;
-	      isect = test_insideness(((tmpl1 + tmpl2) >> 1) - adj.x,
+	      if (slab->anchor & JUSTIFYRIGHT)
+	         padding = (int)tlinfo.padding[tlinfo.line];
+	      else if (slab->anchor & TEXTCENTERED)
+	         padding = (int)(0.5 * tlinfo.padding[tlinfo.line]);
+	      else
+		 padding = 0;
+	      isect = test_insideness(((tmpl1 + tmpl2) >> 1) - adj.x + padding,
 			(tmpext.base + (BASELINE >> 1)) - adj.y, newboxpts);
 
 	      /* tiny state machine */
@@ -1070,6 +1083,8 @@ Boolean selectarea(objectptr selobj, XPoint *boxpts, short level)
 	   }
 	   if (state == 1) areawin->textpos = j;   /* selection goes to end of string */
 
+	   if (tlinfo.padding != NULL) free(tlinfo.padding);
+
 	   /* If a label happens to be empty (can happen in the case of	*/
 	   /* a label with parameters that are all empty strings), then	*/
 	   /* check if the bounding box surrounds the label position.	*/
