@@ -1423,7 +1423,7 @@ static float UDrawChar(u_char code, short styles, short ffont, int groupheight,
    alphapts[0].y = 0;
    charinst.type = OBJINST;
    charinst.color = DEFAULTCOLOR;
-   charinst.rotation = 0;
+   charinst.rotation = 0.0;
    charinst.scale = fonts[ffont].scale;
    charinst.position = alphapts[0];
    charinst.params = NULL;
@@ -1494,7 +1494,7 @@ void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
 {
    stringpart *strptr;
    u_char *textptr;
-   short  fstyle, ffont, tmpjust;
+   short  fstyle, ffont, tmpanchor;
    float  baseline;
    int    pos, group = 0;
    int    defaultcolor, curcolor, scolor;
@@ -1505,8 +1505,10 @@ void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
    XPoint  bboxin[2], bboxout[2];
    u_char xm, ym;
    TextExtents tmpext;
+   TextLinesInfo tlinfo;
    short *tabstops = NULL;
    short tabno, numtabs = 0;
+   short linenum = 0;
 #ifdef HAVE_CAIRO
    cairo_matrix_t fm = {40., 0., 0., -40., 0., 0.}; /* TODO: Why 40? */
 
@@ -1541,17 +1543,21 @@ void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
    UPushCTM();
    UPreMultCTM(DCTM, drawlabel->position, drawlabel->scale, drawlabel->rotation);
 
-   /* check for flip invariance; recompute CTM and justification if necessary */
+   /* check for flip invariance; recompute CTM and anchoring if necessary */
 
-   tmpjust = flipadjust(drawlabel->justify);
+   tmpanchor = flipadjust(drawlabel->anchor);
+
+   tlinfo.dostop = 0;
+   tlinfo.tbreak = NULL;
+   tlinfo.padding = NULL;
 
    /* "natural" (unscaled) length */
-   tmpext = ULength(drawlabel, localinst, 0, NULL);
+   tmpext = ULength(drawlabel, localinst, &tlinfo);
 
-   newpoint.x = (tmpjust & NOTLEFT ?
-       (tmpjust & RIGHT ? -tmpext.maxwidth : -tmpext.maxwidth >> 1) : 0);
-   newpoint.y = (tmpjust & NOTBOTTOM ?
-       (tmpjust & TOP ? -tmpext.ascent : -(tmpext.ascent + tmpext.base) >> 1)
+   newpoint.x = (tmpanchor & NOTLEFT ?
+       (tmpanchor & RIGHT ? -tmpext.maxwidth : -tmpext.maxwidth >> 1) : 0);
+   newpoint.y = (tmpanchor & NOTBOTTOM ?
+       (tmpanchor & TOP ? -tmpext.ascent : -(tmpext.ascent + tmpext.base) >> 1)
 		: -tmpext.base);
 
    /* Pinlabels have an additional offset spacing to pad */
@@ -1561,7 +1567,7 @@ void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
       XPoint p;
       p.x = newpoint.x;
       p.y = newpoint.y;
-      pinadjust(tmpjust, &p.x, &p.y, 1);
+      pinadjust(tmpanchor, &p.x, &p.y, 1);
       newpoint.x = p.x;
       newpoint.y = p.y;
    }
@@ -1583,6 +1589,18 @@ void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
        bboxout[1 - xm].x > 0 && bboxout[1 - ym].y > 0) {
 
        pos = 0;
+
+       /* At the beginning of the line, add offsets for right or center	*/
+       /* justification, if required.					*/
+
+       if (tlinfo.padding != NULL) {
+	  if (tmpanchor & JUSTIFYRIGHT)
+	     newpoint.x += tlinfo.padding[linenum];
+	  else if (tmpanchor & TEXTCENTERED)
+	     newpoint.x += 0.5 * tlinfo.padding[linenum];
+	  linenum++;
+       }
+
        for (strptr = drawlabel->string; strptr != NULL;
 		strptr = nextstringpart(strptr, localinst)) {
 
@@ -1668,8 +1686,16 @@ void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
 		baseline -= BASELINE;
 	        newpoint.y = baseline;
 		newpoint.x = oldx;
+
+	        if (tlinfo.padding != NULL) {
+	 	  if (tmpanchor & JUSTIFYRIGHT)
+	 	     newpoint.x += tlinfo.padding[linenum];
+	 	  else if (tmpanchor & TEXTCENTERED)
+	 	     newpoint.x += 0.5 * tlinfo.padding[linenum];
+		  linenum++;
+	        }
 		break;
-	
+
 	     case SUBSCRIPT:
 	        natscale *= SUBSCALE; 
 		tmpscale = natscale;
@@ -1798,6 +1824,7 @@ void UDrawString0(labelptr drawlabel, int passcolor, objinstptr localinst,
    /* enddraw: (jdk) */
 
    if (tabstops != NULL) free(tabstops);
+   if (tlinfo.padding != NULL) free(tlinfo.padding);
 
    /* Pop the string transformation matrix */
 
@@ -1831,11 +1858,32 @@ void UDrawStringNoX(labelptr drawlabel, int passcolor, objinstptr localinst)
 
 /*----------------------------------------------------------------------*/
 /* Compute the actual length of a string or portion thereof.		*/
+/*									*/
+/* The third argument is a pointer to a structure TextLinesInfo, having	*/
+/* fields "dostop", "tbreak", and "padding".  The third argument may	*/
+/* be NULL, in which case dostop defaults to 0 and tbreak and 		*/
+/* padding default to NULL.						*/
+/*									*/
+/* If "dostop" is non-zero, ULength computes the length to a specific	*/
+/* location in the string.						*/
+/* If "padding" is non-NULL, it is a pointer to an array to be		*/
+/* allocated and filled in with the individual padding lengths.  If	*/
+/* the array is already allocated, then it is assumed to contain valid	*/
+/* linewidth information from a previous call to ULength().		*/
+/* If "tbreak" is non-NULL, it is a pointer to an XPoint, and the	*/
+/* return TextExtents record "width" will be filled in with the index	*/
+/* position in the string that is closest to that point.		*/
+/* When using either "dostop" or "tbreak", the line number stopped on	*/
+/* is returned in TextLinesInfo field "line".  When using "tbreak", the	*/
+/* position index is returned in "dostop".				*/
 /*----------------------------------------------------------------------*/
 
 TextExtents ULength(labelptr drawlabel, objinstptr localinst,
-	short dostop, XPoint *tbreak)
+	TextLinesInfo *tlinfo)
 {
+   short dostop;
+   XPoint tbreak;
+
    float oldscale, strscale, natscale, locscale = 1.0, xtotal = 0.5;
    float lasttotal = xtotal;
    stringpart *strptr;
@@ -1846,11 +1894,14 @@ TextExtents ULength(labelptr drawlabel, objinstptr localinst,
    TextExtents retext;
    short *tabstops = NULL;
    short tabno, numtabs = 0;
+   short linenum = 0;
    Boolean dobreak = FALSE;
 #ifdef HAVE_CAIRO
    fontinfo *font = NULL;
 #endif /* HAVE_CAIRO */
 
+   dostop = (tlinfo == NULL) ? 0 : tlinfo->dostop;
+
    retext.ascent = retext.descent = retext.base = 0;
    retext.width = retext.maxwidth = 0;
 
@@ -1859,8 +1910,18 @@ TextExtents ULength(labelptr drawlabel, objinstptr localinst,
    /* Don't draw temporary labels from schematic capture system */
    else if (drawlabel->string->type != FONT_NAME) return retext;
 
+   /* Copy tbreak point locally */
+   if ((tlinfo != NULL) && (tlinfo->tbreak != NULL)) tbreak = *tlinfo->tbreak;
+
+   /* Adjust tbreak x value for justification */
+   if ((tlinfo != NULL) && (tlinfo->padding != NULL)) {
+      if (drawlabel->anchor & JUSTIFYRIGHT)
+         tbreak.x -= tlinfo->padding[linenum];
+      else if (drawlabel->anchor & TEXTCENTERED)
+         tbreak.x -= 0.5 * tlinfo->padding[linenum];
+   }
+
    natscale = 1.0;
-     
    oldscale = strscale = natscale;
 
    for (strptr = drawlabel->string; strptr != NULL;
@@ -1881,12 +1942,36 @@ TextExtents ULength(labelptr drawlabel, objinstptr localinst,
 	    ykern = 0.0;
 	    break;
 	 case RETURN:
+	    if (tlinfo != NULL) {
+	       if (tlinfo->padding == NULL) {
+	          stringpart *nextret = strptr;
+	          int numlines = 2;
+	          while ((nextret = nextstringpart(nextret, localinst)) != NULL)
+		     if (nextret->type == RETURN)
+		        numlines++;
+	          tlinfo->padding = (float *)malloc(numlines * sizeof(float));
+	       }
+	       if (tlinfo->padding != NULL)
+		  tlinfo->padding[linenum++] = xtotal;
+	    }
 	    natscale = strscale = oldscale;
 	    ykern = 0.0;
 	    retext.base -= BASELINE;
 	    retext.maxwidth = max(retext.width, retext.maxwidth);
 	    retext.maxwidth = max(retext.maxwidth, xtotal);
 	    xtotal = 0.5;
+
+	    /* Re-copy tbreak point locally */
+	    if ((tlinfo != NULL) && (tlinfo->tbreak != NULL))
+	       tbreak = *tlinfo->tbreak;
+
+	    /* Adjust tbreak x value for justification on next line */
+	    if ((tlinfo != NULL) && (tlinfo->padding != NULL)) {
+	       if (drawlabel->anchor & JUSTIFYRIGHT)
+	          tbreak.x -= tlinfo->padding[linenum];
+	       else if (drawlabel->anchor & TEXTCENTERED)
+	          tbreak.x -= 0.5 * tlinfo->padding[linenum];
+	    }
 	    break;
 	 case HALFSPACE: 
 	    if (somebet) {
@@ -1993,34 +2078,53 @@ TextExtents ULength(labelptr drawlabel, objinstptr localinst,
 	       retext.descent = min(retext.descent, (short)(retext.base + ykern
 		     + bottom * locscale * strscale));
 
-               if (tbreak != NULL) 
-	          if ((xtotal > tbreak->x) && (retext.base <= tbreak->y)) {
+	       if ((tlinfo != NULL) && (tlinfo->tbreak != NULL)) {
+	          if ((xtotal > tbreak.x) && (retext.base <= tbreak.y)) {
 		     dobreak = TRUE;
 		     break;
 		  }
+	       }
                lasttotal = xtotal;
 	       lastpos = locpos;
 	    }
 	    break;
       }
+
       if (strptr->type != TEXT_STRING) locpos++;
       if (dostop && (locpos >= dostop)) break;
       if (dobreak) break;
    }
    if (tabstops != NULL) free(tabstops);
 
-   /* special case: return character position in retext.width */
-   if (tbreak != NULL) {
+   /* Update width and maxwidth entries */
+   retext.width = max(retext.width, xtotal);
+   retext.maxwidth = max(retext.maxwidth, xtotal);
+
+   /* If not doing "dostop", put the last position into the 	*/
+   /* list of padding.	Since padding values are currently	*/
+   /* linewidths, subtract them from maxwidth.			*/
+
+   if (tlinfo != NULL) {
+      int i;
+      if ((tlinfo->dostop == 0) && (tlinfo->padding != NULL)) {
+	  tlinfo->padding[linenum] = xtotal;
+	  for (i = 0; i <= linenum; i++)
+	     tlinfo->padding[i] = retext.maxwidth - tlinfo->padding[i];
+      }
+      tlinfo->line = linenum;
+   }
+
+   /* Return character position in tlinfo->dostop (which should	*/
+   /* be unused if using "tbreak" 				*/
+
+   if ((tlinfo != NULL) && (tlinfo->tbreak != NULL)) {
       int slen = stringlength(drawlabel->string, True, localinst);
-      if ((tbreak->x - lasttotal) < (xtotal - tbreak->x))
+      if ((tbreak.x - lasttotal) < (xtotal - tbreak.x))
 	 locpos = lastpos + 1;
       if (locpos < 1) locpos = 1;
       else if (locpos > slen) locpos = slen;
-      retext.width = locpos;
-      return retext;
+      if (tlinfo != NULL) tlinfo->dostop = locpos;
    }
-   retext.width = max(retext.width, xtotal);
-   retext.maxwidth = max(retext.maxwidth, xtotal);
    return retext;
 }
 
@@ -2073,6 +2177,7 @@ void InsertMarginNewlines(labelptr settext, objinstptr localinst)
    int margin = 0;
    int strpos = 0, locpos, slen, savelen;
    TextExtents tmpext;
+   TextLinesInfo tlinfo;
 
    /* 1) Find the position of the margin stop.  Track position	*/
    /* in string a la findstringpart(), as we need to pass this	*/
@@ -2103,6 +2208,9 @@ void InsertMarginNewlines(labelptr settext, objinstptr localinst)
    /* 2) Compute the drawn string length at each word break.  When a	*/
    /*    word overruns the margin, place a line break in front of it.	*/
 
+   tlinfo.tbreak = NULL;
+   tlinfo.padding = NULL;
+
    while (1) {
       strptr = findstringpart(strpos, &locpos, settext->string, localinst);
       if (strptr == NULL) break;
@@ -2110,7 +2218,10 @@ void InsertMarginNewlines(labelptr settext, objinstptr localinst)
 	 slen = strlen(strptr->data.string);
 	 /* Ignore trailing spaces */
 	 while ((slen > 0) && (*(strptr->data.string + slen - 1) == ' ')) slen--;
-         tmpext = ULength(settext, localinst, strpos + slen, NULL);
+
+	 tlinfo.dostop = strpos + slen;
+
+         tmpext = ULength(settext, localinst, &tlinfo);
 	 if (tmpext.width > margin) {
 	    savelen = 0;
             while ((slen > 0) && (tmpext.width > margin)) {
@@ -2119,7 +2230,8 @@ void InsertMarginNewlines(labelptr settext, objinstptr localinst)
 		  slen--;
 		  savelen = slen;
 	       }
-	       tmpext = ULength(settext, localinst, strpos + slen - 1, NULL);
+	       tlinfo.dostop = strpos + slen - 1;
+	       tmpext = ULength(settext, localinst, &tlinfo);
 	    }
 	    /* Take the first space, in case we have a single word so long that	*/
 	    /* it exceeds the margin by itself.					*/
@@ -2171,6 +2283,7 @@ void CheckMarginStop(labelptr settext, objinstptr localinst, Boolean force)
    stringpart *strptr;
    int margin = 0;
    TextExtents tmpext;
+   TextLinesInfo tlinfo;
 
    for (strptr = settext->string; strptr != NULL;
 		strptr = nextstringpart(strptr, localinst)) {
@@ -2182,7 +2295,10 @@ void CheckMarginStop(labelptr settext, objinstptr localinst, Boolean force)
       if (margin > 0) break;
    }
    if (margin > 0) {
-      tmpext = ULength(settext, localinst, 0, NULL);
+      tlinfo.dostop = 0;
+      tlinfo.tbreak = NULL;
+      tlinfo.padding = NULL;
+      tmpext = ULength(settext, localinst, &tlinfo);
       if ((force == TRUE) || (tmpext.maxwidth > margin)) {
 	 RemoveMarginNewlines(settext, localinst);
 	 InsertMarginNewlines(settext, localinst);
@@ -2312,7 +2428,7 @@ void composefontlib(short cfont)
       schar->nextpart = NULL;
       label = new_label(xobjs.libtop[FONTLIB], sfont, NORMAL,
 	    (i % 16) * del + del / 2, -(i / 16) * del - del / 2 - 32 /2);
-      label->justify = NOTLEFT;
+      label->anchor = NOTLEFT;
       label->color = DEFAULTCOLOR;
    }
 
