@@ -262,7 +262,8 @@ void quit(xcWidget w, caddr_t nulldata)
    /* exit by exiting the Python interpreter, if enabled */
    exit_interpreter();
 #elif defined(TCL_WRAPPER)
-   exit(0);	/* For now, exit.  Later, clear all pages and return to interp. */
+   /* Let Tcl/Tk handle exit */
+   return;
 #elif defined(XC_WIN32)
    PostQuitMessage(0);
 #else
@@ -1049,7 +1050,7 @@ XCWindowData *create_new_window()
    newwindow->area = (xcWidget)NULL;
    newwindow->mapped = False;
    newwindow->psfont = 0;
-   newwindow->justify = FLIPINV;
+   newwindow->anchor = FLIPINV;
    newwindow->page = 0;
    newwindow->MatStack = NULL;
    newwindow->textscale = 1.0;
@@ -1089,6 +1090,7 @@ XCWindowData *create_new_window()
    newwindow->redraw_ongoing = False;
 #ifdef HAVE_CAIRO
    newwindow->fixed_pixmap = NULL;
+   newwindow->cr = NULL;
 #else /* HAVE_CAIRO */
    newwindow->clipmask = (Pixmap)NULL;
    newwindow->pbuf = (Pixmap)NULL;
@@ -1144,6 +1146,7 @@ void pre_initialize()
    for (page = 0; page < PAGES; page++) {
       xobjs.pagelist[page] = (Pagedata *) malloc(sizeof(Pagedata));
       xobjs.pagelist[page]->pageinst = NULL;
+      xobjs.pagelist[page]->filename = NULL;
    }
    /* Set values for the first page */
    xobjs.pagelist[0]->wirewidth = 2.0;
@@ -1162,7 +1165,7 @@ void pre_initialize()
 
    xobjs.hold = TRUE;
    xobjs.showtech = FALSE;
-   xobjs.suspend = (char)0;	/* Suspend graphics until finished with startup */
+   xobjs.suspend = (signed char)0; /* Suspend graphics until finished with startup */
    xobjs.new_changes = 0;
    xobjs.filefilter = TRUE;
    xobjs.tempfile = NULL;
@@ -1254,7 +1257,7 @@ SetHandleFromAny(interp, objPtr)
     Tcl_Interp *interp;         /* Used for error reporting if not NULL. */
     Tcl_Obj *objPtr;   /* The object to convert. */
 {  
-    Tcl_ObjType *oldTypePtr = objPtr->typePtr;
+    Tcl_ObjType *oldTypePtr = (Tcl_ObjType *)objPtr->typePtr;
     char *string, *end;
     int length;
     char *p;
