@@ -88,9 +88,9 @@ void togglegridstyles(xcWidget button) {
       toggleexcl(button, GridStyles, XtNumber(GridStyles));
 }
 
-void togglejustifs(xcWidget button) {
+void toggleanchors(xcWidget button) {
    if (button != NULL)
-      toggleexcl(button, Justifs, XtNumber(Justifs));
+      toggleexcl(button, Anchors, XtNumber(Anchors));
 }
 
 void togglefontstyles(xcWidget button) {
@@ -104,108 +104,108 @@ void toggleencodings(xcWidget button) {
 }
 
 /*--------------------------------------------------------------*/
-/* Toggle a bit in the justification field of a label		*/
+/* Toggle a bit in the anchoring field of a label		*/
 /*--------------------------------------------------------------*/
 
-void dojustifybit(xcWidget w, labelptr settext, short bitfield)
+void doanchorbit(xcWidget w, labelptr settext, short bitfield)
 {
    if (settext != NULL) {
-      int oldjust = (int)settext->justify;
+      int oldanchor = (int)settext->anchor;
 
       undrawtext(settext);
-      settext->justify ^= bitfield;
+      settext->anchor ^= bitfield;
       redrawtext(settext);
       pwriteback(areawin->topinstance);
 
-      register_for_undo(XCF_Justify, UNDO_MORE, areawin->topinstance,
-		(genericptr)settext, oldjust);
+      register_for_undo(XCF_Anchor, UNDO_MORE, areawin->topinstance,
+		(genericptr)settext, oldanchor);
    }
    else
-      areawin->justify ^= bitfield;
+      areawin->anchor ^= bitfield;
 
    if (w != NULL) {
       Boolean boolval;
       if (settext)
-	 boolval = (settext->justify & bitfield) ? 0 : 1;
+	 boolval = (settext->anchor & bitfield) ? 0 : 1;
       else
-	 boolval = (areawin->justify & bitfield) ? 0 : 1;
+	 boolval = (areawin->anchor & bitfield) ? 0 : 1;
       toggle(w, (pointertype)(-1), &boolval);
    }
 }
 
 /*--------------------------------------------------------------*/
-/* Toggle a pin-related bit in the justification field of a	*/
-/* label.  This differs from dojustifybit() in that the label	*/
+/* Toggle a pin-related bit in the anchoring field of a		*/
+/* label.  This differs from doanchorbit() in that the label	*/
 /* must be a pin, and this function cannot change the default	*/
-/* behavior set by areawin->justify.				*/
+/* behavior set by areawin->anchor.				*/
 /*--------------------------------------------------------------*/
 
-void dopinjustbit(xcWidget w, labelptr settext, short bitfield)
+void dopinanchorbit(xcWidget w, labelptr settext, short bitfield)
 {
    if ((settext != NULL) && settext->pin) {
-      int oldjust = (int)settext->justify;
+      int oldanchor = (int)settext->anchor;
 
       undrawtext(settext);
-      settext->justify ^= bitfield;
+      settext->anchor ^= bitfield;
       redrawtext(settext);
       pwriteback(areawin->topinstance);
 
-      register_for_undo(XCF_Justify, UNDO_MORE, areawin->topinstance,
-		(genericptr)settext, oldjust);
+      register_for_undo(XCF_Anchor, UNDO_MORE, areawin->topinstance,
+		(genericptr)settext, oldanchor);
 
       if (w != NULL) {
-	 Boolean boolval = (settext->justify & bitfield) ? 0 : 1;
+	 Boolean boolval = (settext->anchor & bitfield) ? 0 : 1;
 	 toggle(w, (pointertype)(-1), &boolval);
       }
    }
 }
 
 /*----------------------------------------------------------------*/
-/* Set the justification for the label passed as 3rd parameter	  */
+/* Set the anchoring for the label passed as 3rd parameter	  */
 /*----------------------------------------------------------------*/
 
-void setjust(xcWidget w, pointertype value, labelptr settext, short mode)
+void setanchor(xcWidget w, pointertype value, labelptr settext, short mode)
 {
-   short newjust, oldjust;
+   short newanchor, oldanchor;
 
    if (settext != NULL) {
 
       if (mode == 1)
-         newjust = (settext->justify & (NONJUSTFIELD | TBJUSTFIELD))
+         newanchor = (settext->anchor & (NONANCHORFIELD | TBANCHORFIELD))
 			| value;
       else
-         newjust = (settext->justify & (NONJUSTFIELD | RLJUSTFIELD))
+         newanchor = (settext->anchor & (NONANCHORFIELD | RLANCHORFIELD))
 			| value;
 
-      if (settext->justify != newjust) {
-	  oldjust = (int)settext->justify;
+      if (settext->anchor != newanchor) {
+	  oldanchor = (int)settext->anchor;
           undrawtext(settext);
-          settext->justify = newjust;
+          settext->anchor = newanchor;
           redrawtext(settext);
           pwriteback(areawin->topinstance);
 
-          register_for_undo(XCF_Justify, UNDO_MORE, areawin->topinstance,
-		(genericptr)settext, oldjust);
+          register_for_undo(XCF_Anchor, UNDO_MORE, areawin->topinstance,
+		(genericptr)settext, oldanchor);
       }
    }
    else {
       if (mode == 1)
-         newjust = (areawin->justify & (NONJUSTFIELD | TBJUSTFIELD))
+         newanchor = (areawin->anchor & (NONANCHORFIELD | TBANCHORFIELD))
 			| value;
       else
-         newjust = (areawin->justify & (NONJUSTFIELD | RLJUSTFIELD))
+         newanchor = (areawin->anchor & (NONANCHORFIELD | RLANCHORFIELD))
 			| value;
-      areawin->justify = newjust;
+      areawin->anchor = newanchor;
    }
-   if (w != NULL) togglejustifs(w);
+   if (w != NULL) toggleanchors(w);
 }
 
-/*----------------------------------------------------------------*/
-/* Set vertical justification (top, middle, bottom) on all	  */
-/* selected labels						  */
-/*----------------------------------------------------------------*/
+/*--------------------------------------------------------------*/
+/* Set vertical anchoring (top, middle, bottom) on all	  	*/
+/* selected labels						*/
+/*--------------------------------------------------------------*/
 
-void setvjust(xcWidget w, pointertype value, caddr_t nulldata)
+void setvanchor(xcWidget w, pointertype value, caddr_t nulldata)
 {
    short *fselect;
    labelptr settext;
@@ -213,7 +213,7 @@ void setvjust(xcWidget w, pointertype value, caddr_t nulldata)
 
    if (eventmode == TEXT_MODE || eventmode == ETEXT_MODE) {
       settext = *((labelptr *)EDITPART);
-      setjust(w, value, settext, 2);
+      setanchor(w, value, settext, 2);
    }
    else {
       for (fselect = areawin->selectlist; fselect < areawin->selectlist +
@@ -221,20 +221,20 @@ void setvjust(xcWidget w, pointertype value, caddr_t nulldata)
          if (SELECTTYPE(fselect) == LABEL) {
             labelcount++;
             settext = SELTOLABEL(fselect);
-            setjust(NULL, value, settext, 2);
+            setanchor(NULL, value, settext, 2);
          }
       }
-      if (labelcount == 0) setjust(w, value, NULL, 2);
+      if (labelcount == 0) setanchor(w, value, NULL, 2);
       else unselect_all();
    }
 }
 
 /*----------------------------------------------------------------*/
-/* Set horizontal justification (left, center, right) on all	  */
+/* Set horizontal anchoring (left, center, right) on all	  */
 /* selected labels						  */
 /*----------------------------------------------------------------*/
 
-void sethjust(xcWidget w, pointertype value, caddr_t nulldata)
+void sethanchor(xcWidget w, pointertype value, caddr_t nulldata)
 {
    short *fselect;
    labelptr settext;
@@ -242,7 +242,7 @@ void sethjust(xcWidget w, pointertype value, caddr_t nulldata)
 
    if (eventmode == TEXT_MODE || eventmode == ETEXT_MODE) {
       settext = *((labelptr *)EDITPART);
-      setjust(w, value, settext, 1);
+      setanchor(w, value, settext, 1);
    }
    else {
       for (fselect = areawin->selectlist; fselect < areawin->selectlist +
@@ -250,20 +250,20 @@ void sethjust(xcWidget w, pointertype value, caddr_t nulldata)
          if (SELECTTYPE(fselect) == LABEL) {
             labelcount++;
             settext = SELTOLABEL(fselect);
-            setjust(NULL, value, settext, 1);
+            setanchor(NULL, value, settext, 1);
          }
       }
-      if (labelcount == 0) setjust(w, value, NULL, 1);
+      if (labelcount == 0) setanchor(w, value, NULL, 1);
       else unselect_all();
    }
 }
 
 /*--------------------------------------------------------------*/
-/* Set a justify field bit on all selected labels		*/ 
+/* Set an anchor field bit on all selected labels		*/ 
 /* (flip invariance, latex mode, etc.)				*/
 /*--------------------------------------------------------------*/
 
-void setjustbit(xcWidget w, pointertype value, caddr_t nulldata)
+void setanchorbit(xcWidget w, pointertype value, caddr_t nulldata)
 {
    short *fselect;
    labelptr settext;
@@ -271,7 +271,7 @@ void setjustbit(xcWidget w, pointertype value, caddr_t nulldata)
 
    if (eventmode == TEXT_MODE || eventmode == ETEXT_MODE) {
       settext = *((labelptr *)EDITPART);
-      dojustifybit(w, settext, (short)value);
+      doanchorbit(w, settext, (short)value);
    }
    else {
       for (fselect = areawin->selectlist; fselect < areawin->selectlist +
@@ -279,20 +279,20 @@ void setjustbit(xcWidget w, pointertype value, caddr_t nulldata)
          if (SELECTTYPE(fselect) == LABEL) {
             labelcount++;
             settext = SELTOLABEL(fselect);
-            dojustifybit(NULL, settext, (short)value);
+            doanchorbit(NULL, settext, (short)value);
          }
       }
-      if (labelcount == 0) dojustifybit(w, NULL, (short)value);
+      if (labelcount == 0) doanchorbit(w, NULL, (short)value);
       else unselect_all();
    }
 }
 
 /*--------------------------------------------------------------*/
-/* Set pin-related bit field of "justify" on all selected pins	*/ 
+/* Set pin-related bit field of "anchor" on all selected pins	*/ 
 /* (e.g., pin visibility)					*/
 /*--------------------------------------------------------------*/
 
-void setpinjustbit(xcWidget w, pointertype value, caddr_t nulldata)
+void setpinanchorbit(xcWidget w, pointertype value, caddr_t nulldata)
 {
    short *fselect;
    labelptr settext;
@@ -300,7 +300,7 @@ void setpinjustbit(xcWidget w, pointertype value, caddr_t nulldata)
    if (eventmode == TEXT_MODE || eventmode == ETEXT_MODE) {
       settext = *((labelptr *)EDITPART);
       if (settext->pin)
-	 dopinjustbit(w, settext, (short)value);
+	 dopinanchorbit(w, settext, (short)value);
    }
    else {
       for (fselect = areawin->selectlist; fselect < areawin->selectlist +
@@ -308,7 +308,7 @@ void setpinjustbit(xcWidget w, pointertype value, caddr_t nulldata)
          if (SELECTTYPE(fselect) == LABEL) {
             settext = SELTOLABEL(fselect);
 	    if (settext->pin)
-               dopinjustbit(NULL, settext, (short)value);
+               dopinanchorbit(NULL, settext, (short)value);
          }
       }
       unselect_all();
@@ -1655,23 +1655,23 @@ void setfontmarks(short fvalue, short jvalue)
       togglefontmark(fvalue);
    }
    if (jvalue >= 0) {
-      switch(jvalue & (RLJUSTFIELD)) {
-         case NORMAL: w = JustificationLeftJustifiedButton; break;
-         case NOTLEFT: w = JustificationCenterJustifiedButton; break;
-         case RIGHT|NOTLEFT: w = JustificationRightJustifiedButton; break;
+      switch(jvalue & (RLANCHORFIELD)) {
+         case NORMAL: w = AnchoringLeftAnchoredButton; break;
+         case NOTLEFT: w = AnchoringCenterAnchoredButton; break;
+         case RIGHT|NOTLEFT: w = AnchoringRightAnchoredButton; break;
       }
-      toggleexcl(w, Justifs, XtNumber(Justifs));
+      toggleexcl(w, Anchors, XtNumber(Anchors));
 
-      switch(jvalue & (TBJUSTFIELD)) {
-         case NORMAL: w = JustificationBottomJustifiedButton; break;
-         case NOTBOTTOM: w = JustificationMiddleJustifiedButton; break;
-         case TOP|NOTBOTTOM: w = JustificationTopJustifiedButton; break;
+      switch(jvalue & (TBANCHORFIELD)) {
+         case NORMAL: w = AnchoringBottomAnchoredButton; break;
+         case NOTBOTTOM: w = AnchoringMiddleAnchoredButton; break;
+         case TOP|NOTBOTTOM: w = AnchoringTopAnchoredButton; break;
       }
 
-      toggleexcl(w, Justifs, XtNumber(Justifs));
+      toggleexcl(w, Anchors, XtNumber(Anchors));
 
       /* Flip Invariance property */
-      w = JustificationFlipInvariantButton;
+      w = AnchoringFlipInvariantButton;
       if (jvalue & FLIPINV)
          XtSetArg(wargs[0], XtNsetMark, True);
       else
