@@ -88,7 +88,6 @@ extern Cursor appcursors[NUM_CURSORS];
 extern ApplicationData appdata;
 extern XCWindowData *areawin;
 extern Globaldata xobjs;
-extern int *appcolors;
 extern int number_colors;
 extern colorindex *colorlist;
 extern short menusize;
@@ -107,10 +106,7 @@ extern Pixmap helppix;
 extern aliasptr aliastop;
 extern float version;
 
-#ifndef OPENGL
-static
-#endif
-char STIPDATA[STIPPLES][4] = {
+static char STIPDATA[STIPPLES][4] = {
    "\000\004\000\001",
    "\000\005\000\012",
    "\001\012\005\010",
@@ -121,9 +117,7 @@ char STIPDATA[STIPPLES][4] = {
    "\000\000\000\000"
 };
 
-#ifdef DOUBLEBUFFER
 extern Pixmap dbuf;
-#endif
 
 /* Bad hack for problems with the DECstation. . . don't know why */
 #ifdef UniqueContextProblem
@@ -247,7 +241,7 @@ int addnewcolorentry(int ccolor)
 
    /* check to see if entry is already in the color list */
 
-   for (i = 0; i < number_colors; i++)
+   for (i = NUMBER_OF_COLORS; i < number_colors; i++)
       if (colorlist[i].color.pixel == ccolor) break;
 
    /* make new entry in the menu */
@@ -1108,7 +1102,7 @@ void outputpopup(xcWidget button, caddr_t clientdata, caddr_t calldata)
    XtnSetArg(XtNstring, request);
    XtnSetArg(XtNborderWidth, 0);
    XtnSetArg(XtNgravity, WestGravity);
-   XtnSetArg(XtNbackground, BARCOLOR);
+   XtnSetArg(XtNbackground, colorlist[BARCOLOR].color.pixel);
    XtnSetArg(XtNfont, appdata.xcfont);
    titlearea = XtCreateManagedWidget("title", XwstaticTextWidgetClass,
 	dialog, wargs, n); n = 0;
@@ -1660,9 +1654,8 @@ XCWindowData *GUI_init(int argc, char *argv[])
       /* Allocate space for the basic color map */
       /*----------------------------------------*/
 
-      number_colors = 0;
-      colorlist = (colorindex *)malloc(sizeof(colorindex));
-      appcolors = (int *) malloc(NUMBER_OF_COLORS * sizeof(int));
+      number_colors = NUMBER_OF_COLORS;
+      colorlist = (colorindex *)malloc(NUMBER_OF_COLORS * sizeof(colorindex));
 
       /*-----------------------------------------------------------*/
       /* Xw must add these translations for the popup manager      */
